pub async fn find_partition(
device_label: String,
) -> Result<Box<dyn BlockConnector>>Expand description
Find an existing test partition using the device label and return a block connector for it.
pub async fn find_partition(
device_label: String,
) -> Result<Box<dyn BlockConnector>>Find an existing test partition using the device label and return a block connector for it.