pub async fn set_up_partition(
device_label: String,
) -> Result<Box<dyn BlockConnector>>Expand description
Set up a partition for testing using the device label, returning a block connector for it. If the partition already exists with this label, it’s used. If no existing device is found with this label, create a new gpt partition to use.